==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.find/src/com/openexchange/find/osgi/FindActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.find.osgi;

import org.osgi.framework.BundleContext;
import org.slf4j.Logger;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.find.SearchService;
import com.openexchange.find.internal.AvailableModules;
import com.openexchange.find.internal.MandatoryAccounts;
import com.openexchange.find.internal.MandatoryFolders;
import com.openexchange.find.internal.SearchDriverManager;
import com.openexchange.find.internal.SearchServiceImpl;
import com.openexchange.find.spi.ModuleSearchDriver;
import com.openexchange.groupware.settings.PreferencesItemService;
import com.openexchange.jslob.ConfigTreeEquivalent;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * The activator for find bundle.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a> Exception handling + logging
 * @since 7.6.0
 */
public class FindActivator extends HousekeepingActivator {

    private static final Logger LOG = org.slf4j.LoggerFactory.getLogger(FindActivator.class);

    /**
     * Initializes a new {@link FindActivator}.
     */
    public FindActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigViewFactory.class };
    }

    @Override
    protected void startBundle() throws Exception {
        LOG.info("Starting bundle: com.openexchange.find");
        try {
            final SearchDriverManager driverManager = new SearchDriverManager(context, getService(ConfigViewFactory.class));
            track(ModuleSearchDriver.class, driverManager);
            openTrackers();

            final SearchServiceImpl searchService = new SearchServiceImpl(driverManager);
            registerService(SearchService.class, searchService);

            final MandatoryFolders mandatoryFolders = new MandatoryFolders(driverManager);
            registerService(PreferencesItemService.class, mandatoryFolders);
            registerService(ConfigTreeEquivalent.class, mandatoryFolders);

            final MandatoryAccounts mandatoryAccounts = new MandatoryAccounts(driverManager);
            registerService(PreferencesItemService.class, mandatoryAccounts);
            registerService(ConfigTreeEquivalent.class, mandatoryAccounts);

            final AvailableModules availableModules = new AvailableModules(driverManager);
            registerService(PreferencesItemService.class, availableModules);
            registerService(ConfigTreeEquivalent.class, availableModules);

            LOG.info("Bundle successfully started: com.openexchange.find");
        } catch (final Exception e) {
            LOG.error("Error while starting bundle: com.openexchange.find", e);
            throw e;
        }
    }

    @Override
    public void stop(final BundleContext context) throws Exception {
        LOG.info("Stopping bundle: com.openexchange.find");
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.find/src/com/openexchange/find/osgi/FindActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.find.osgi;

import org.osgi.framework.BundleContext;
import org.slf4j.Logger;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.config.lean.LeanConfigurationService;
import com.openexchange.find.SearchService;
import com.openexchange.find.internal.AvailableModules;
import com.openexchange.find.internal.MandatoryAccounts;
import com.openexchange.find.internal.MandatoryFolders;
import com.openexchange.find.internal.SearchDriverManager;
import com.openexchange.find.internal.SearchServiceImpl;
import com.openexchange.find.spi.ModuleSearchDriver;
import com.openexchange.groupware.settings.PreferencesItemService;
import com.openexchange.i18n.I18nServiceRegistry;
import com.openexchange.jslob.ConfigTreeEquivalent;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * The activator for find bundle.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a> Exception handling + logging
 * @since 7.6.0
 */
public class FindActivator extends HousekeepingActivator {

    private static final Logger LOG = org.slf4j.LoggerFactory.getLogger(FindActivator.class);

    /**
     * Initializes a new {@link FindActivator}.
     */
    public FindActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigViewFactory.class, LeanConfigurationService.class, I18nServiceRegistry.class };
    }

    @Override
    protected void startBundle() throws Exception {
        LOG.info("Starting bundle: com.openexchange.find");
        Services.setServiceLookup(this);
        try {
            final SearchDriverManager driverManager = new SearchDriverManager(context, getService(ConfigViewFactory.class));
            track(ModuleSearchDriver.class, driverManager);
            openTrackers();

            final SearchServiceImpl searchService = new SearchServiceImpl(driverManager);
            registerService(SearchService.class, searchService);

            final MandatoryFolders mandatoryFolders = new MandatoryFolders(driverManager);
            registerService(PreferencesItemService.class, mandatoryFolders);
            registerService(ConfigTreeEquivalent.class, mandatoryFolders);

            final MandatoryAccounts mandatoryAccounts = new MandatoryAccounts(driverManager);
            registerService(PreferencesItemService.class, mandatoryAccounts);
            registerService(ConfigTreeEquivalent.class, mandatoryAccounts);

            final AvailableModules availableModules = new AvailableModules(driverManager);
            registerService(PreferencesItemService.class, availableModules);
            registerService(ConfigTreeEquivalent.class, availableModules);

            LOG.info("Bundle successfully started: com.openexchange.find");
        } catch (final Exception e) {
            LOG.error("Error while starting bundle: com.openexchange.find", e);
            throw e;
        }
    }

    @Override
    public void stop(final BundleContext context) throws Exception {
        LOG.info("Stopping bundle: com.openexchange.find");
    }

}
